@@ -1,5 +1,6 @@
 class BirdbrainState:
     def __init__(self):
+        self.cache = {}
         self.display_map = BirdbrainState.microbit_empty_display_map()
 
     def display_map_clear(self):
@@ -19,6 +20,21 @@ class BirdbrainState:
 
         return "/".join(self.display_map_normalize())
 
+    def set(self, name, value):
+        if value == None:
+            if name in self.cache:
+                self.cache.pop(name)
+        else:
+            self.cache[name] = value
+
+        return value
+
+    def get(self, name):
+        if name in self.cache:
+            return self.cache[name]
+        else:
+            return None
+
     @classmethod
     def microbit_empty_display_map(self):
         return([0] * 25)
