@@ -13,6 +13,11 @@ def test_bad_device():
         hummingbird = BirdbrainDevice.connect("Z")
     assert e.value.message == "Invalid device name: Z"
 
+def test_stop_all():
+    hummingbird = BirdbrainDevice.connect()
+
+    hummingbird.stop_all()
+
 def test_default_connect():
     hummingbird = BirdbrainDevice.connect()
 
@@ -50,3 +55,21 @@ def test_is_finch():
     hummingbird = BirdbrainDevice.connect("A")
 
     assert not hummingbird.is_finch()
+
+def test_cache():
+    hummingbird = BirdbrainDevice.connect("A")
+
+    assert hummingbird.get_cache("something_name") == None
+
+    assert hummingbird.set_cache("something_name", "something") == "something"
+    assert hummingbird.get_cache("something_name") == "something"
+
+    assert "something_name" in hummingbird.state.cache
+
+    assert hummingbird.set_cache("something_name", None) == None
+
+    assert "something_name" not in hummingbird.state.cache
+
+    assert hummingbird.get_cache("something_name") == None
+
+    assert hummingbird.set_cache("set_not_in_the_cache", None) == None
\ No newline at end of file
